summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--os-plugins/plugins/xserver/OpenSLX/Distro/Debian.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/os-plugins/plugins/xserver/OpenSLX/Distro/Debian.pm b/os-plugins/plugins/xserver/OpenSLX/Distro/Debian.pm
index 2f6e3f7b..29156e60 100644
--- a/os-plugins/plugins/xserver/OpenSLX/Distro/Debian.pm
+++ b/os-plugins/plugins/xserver/OpenSLX/Distro/Debian.pm
@@ -8,11 +8,11 @@
#
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
# xserver/OpenSLX/Distro/Ubuntu.pm
# - provides Ubuntu-specific overrides of the distro API for the xserver
# plugin.
# -----------------------------------------------------------------------------
-package xserver::OpenSLX::Distro::Ubuntu;
+package xserver::OpenSLX::Distro::Debian;
use strict;
use warnings;
@@ -8,11 +8,11 @@
# General information about OpenSLX can be found at http://openslx.org/
# -----------------------------------------------------------------------------
-# xserver/OpenSLX/Distro/Ubuntu.pm
-# - provides Ubuntu-specific overrides of the distro API for the xserver
+# xserver/OpenSLX/Distro/Debian.pm
+# - provides Debian-specific overrides of the distro API for the xserver
# plugin.
# -----------------------------------------------------------------------------